import React from 'react';
import { Text, TouchableOpacity, View } from 'react-native';

const HighlightText = ({ fullText, highlightWords, highlightColor, styles, textAlignment, onClick }) => {
  const wordsToHighlight = highlightWords.split(',').map(word => word.trim());
  
  const renderedText = fullText.split(' ').map((word, index) => {
    const isHighlighted = wordsToHighlight.some(highlightWord => word.includes(highlightWord));
    const wordStyles = isHighlighted ? { ...styles.fullText, color: highlightColor } : styles.fullText;

    return (
      <Text key={index} style={wordStyles}>
        {word + (index < fullText.split(' ').length - 1 ? ' ' : '')}
      </Text>
    );
  });

  // Establecer la alineación del texto según la prop textAlignment
  const containerStyle = {
    flexDirection: 'row',
    flexWrap: 'wrap',
    justifyContent: textAlignment === 'left' ? 'flex-start' : textAlignment === 'center' ? 'center' : 'flex-end',
  };

  return (
    <TouchableOpacity onPress={onClick} style={{ flex: 1 }}>
      <View style={containerStyle}>
        {renderedText}
      </View>
    </TouchableOpacity>
  );
};

export default HighlightText;
